package Business::EDI::CodeList::GroupControlCount;

use base 'Business::EDI::CodeList';
my $VERSION     = 0.02;
sub list_number {return "0060";}
my $usage       = 'B';  # guessed value

# 0060 Group control count                                    []
# Desc: 
# Repr: 
my %code_hash = (

);
sub get_codes { return \%code_hash; }

1;
